@@ -31,6 +31,7 @@ import java.nio.channels.ReadableByteChannel;
 
 import org.apache.http.nio.ContentDecoder;
 import org.apache.http.nio.reactor.SessionInputBuffer;
+import org.apache.http.annotation.NotThreadSafe;
 import org.apache.http.impl.io.HttpTransportMetricsImpl;
 
 /**
@@ -39,6 +40,7 @@ import org.apache.http.impl.io.HttpTransportMetricsImpl;
  *
  * @since 4.0
  */
+@NotThreadSafe
 public abstract class AbstractContentDecoder implements ContentDecoder {
 
     protected final ReadableByteChannel channel;
