@@ -34,7 +34,9 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.channels.FileChannel;
 
+import org.apache.http.annotation.NotThreadSafe;
 import org.apache.http.entity.AbstractHttpEntity;
+import org.apache.http.entity.ContentType;
 import org.apache.http.nio.ContentEncoder;
 import org.apache.http.nio.ContentEncoderChannel;
 import org.apache.http.nio.FileContentEncoder;
@@ -48,7 +50,10 @@ import org.apache.http.nio.IOControl;
  *
  * @since 4.0
  */
-public class NFileEntity extends AbstractHttpEntity implements ProducingNHttpEntity {
+@SuppressWarnings("deprecation")
+@NotThreadSafe
+public class NFileEntity extends AbstractHttpEntity
+                         implements HttpAsyncContentProducer, ProducingNHttpEntity {
 
     private final File file;
     private FileChannel fileChannel;
@@ -65,7 +70,46 @@ public class NFileEntity extends AbstractHttpEntity implements ProducingNHttpEnt
      * @param contentType the content type of the file.
      * @param useFileChannels flag whether the direct transfer from the file
      *   channel should be attempted.
+     *
+     * @since 4.2
      */
+    public NFileEntity(final File file, final ContentType contentType, boolean useFileChannels) {
+        if (file == null) {
+            throw new IllegalArgumentException("File may not be null");
+        }
+        this.file = file;
+        this.useFileChannels = useFileChannels;
+        if (contentType != null) {
+            setContentType(contentType.toString());
+        }
+    }
+
+    /**
+     * @since 4.2
+     */
+    public NFileEntity(final File file) {
+        if (file == null) {
+            throw new IllegalArgumentException("File may not be null");
+        }
+        this.file = file;
+    }
+    /**
+     * Creates new instance of NFileEntity from the given source {@link File}
+     * with the given content type.
+     *
+     * @param file the source file.
+     * @param contentType the content type of the file.
+     *
+     * @since 4.2
+     */
+    public NFileEntity(final File file, final ContentType contentType) {
+        this(file, contentType, true);
+    }
+
+    /**
+     * @deprecated (4.2) use {@link #NFileEntity(File, ContentType, boolean)}
+     */
+    @Deprecated
     public NFileEntity(final File file, final String contentType, boolean useFileChannels) {
         if (file == null) {
             throw new IllegalArgumentException("File may not be null");
@@ -75,16 +119,34 @@ public class NFileEntity extends AbstractHttpEntity implements ProducingNHttpEnt
         setContentType(contentType);
     }
 
+    /**
+     * @deprecated (4.2) use {@link #NFileEntity(File, ContentType)}
+     */
+    @Deprecated
     public NFileEntity(final File file, final String contentType) {
         this(file, contentType, true);
     }
 
-    public void finish() {
-        try {
-            if(fileChannel != null)
-                fileChannel.close();
-        } catch(IOException ignored) {}
+    /**
+     * {@inheritDoc}
+     *
+     * @since 4.2
+     */
+    public void close() throws IOException {
+        FileChannel local = fileChannel;
         fileChannel = null;
+        if (local != null) {
+            local.close();
+        }
+    }
+
+    /**
+     * {@inheritDoc}
+     *
+     * @deprecated (4.2) use {@link #close()}
+     */
+    public void finish() throws IOException {
+        close();
     }
 
     public long getContentLength() {
@@ -97,26 +159,27 @@ public class NFileEntity extends AbstractHttpEntity implements ProducingNHttpEnt
 
     public void produceContent(ContentEncoder encoder, IOControl ioctrl)
             throws IOException {
-        if(fileChannel == null) {
+        if (fileChannel == null) {
             FileInputStream in = new FileInputStream(file);
             fileChannel = in.getChannel();
             idx = 0;
         }
 
         long transferred;
-        if(useFileChannels && encoder instanceof FileContentEncoder) {
+        if (useFileChannels && encoder instanceof FileContentEncoder) {
             transferred = ((FileContentEncoder)encoder)
                 .transfer(fileChannel, idx, Long.MAX_VALUE);
         } else {
             transferred = fileChannel.
                 transferTo(idx, Long.MAX_VALUE, new ContentEncoderChannel(encoder));
         }
-
-        if(transferred > 0)
+        if (transferred > 0) {
             idx += transferred;
-
-        if(idx >= fileChannel.size())
+        }
+        if (idx >= fileChannel.size()) {
             encoder.complete();
+            close();
+        }
     }
 
     public boolean isStreaming() {
