@@ -29,45 +29,42 @@ package org.apache.http.impl.entity;
 
 import java.io.InputStream;
 
-import junit.framework.TestCase;
-
 import org.apache.http.HttpEntity;
 import org.apache.http.HttpMessage;
 import org.apache.http.ProtocolException;
+import org.apache.http.impl.SessionInputBufferMock;
 import org.apache.http.impl.io.ChunkedInputStream;
 import org.apache.http.impl.io.ContentLengthInputStream;
 import org.apache.http.impl.io.IdentityInputStream;
 import org.apache.http.io.SessionInputBuffer;
-import org.apache.http.mockup.HttpMessageMockup;
-import org.apache.http.mockup.SessionInputBufferMockup;
 import org.apache.http.params.CoreProtocolPNames;
+import org.junit.Assert;
+import org.junit.Test;
 
-public class TestEntityDeserializer extends TestCase {
-
-    public TestEntityDeserializer(String testName) {
-        super(testName);
-    }
+public class TestEntityDeserializer {
 
+    @Test
     public void testIllegalGenerateArg() throws Exception {
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
         try {
             entitygen.deserialize(null, null);
-            fail("IllegalArgumentException should have been thrown");
+            Assert.fail("IllegalArgumentException should have been thrown");
         } catch (IllegalArgumentException ex) {
             // expected
         }
         try {
-            entitygen.deserialize(new SessionInputBufferMockup(new byte[] {}) , null);
-            fail("IllegalArgumentException should have been thrown");
+            entitygen.deserialize(new SessionInputBufferMock(new byte[] {}) , null);
+            Assert.fail("IllegalArgumentException should have been thrown");
         } catch (IllegalArgumentException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityWithTransferEncoding() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup("0\r\n", "US-ASCII");
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock("0\r\n", "US-ASCII");
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
@@ -76,25 +73,26 @@ public class TestEntityDeserializer extends TestCase {
         message.addHeader("Content-Length", "plain wrong");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(-1, entity.getContentLength());
-        assertTrue(entity.isChunked());
-        assertTrue(entity.getContent() instanceof ChunkedInputStream);
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(-1, entity.getContentLength());
+        Assert.assertTrue(entity.isChunked());
+        Assert.assertTrue(entity.getContent() instanceof ChunkedInputStream);
 
         // strict mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, true);
-        entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(-1, entity.getContentLength());
-        assertTrue(entity.isChunked());
-        assertTrue(entity.getContent() instanceof ChunkedInputStream);
+        entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(-1, entity.getContentLength());
+        Assert.assertTrue(entity.isChunked());
+        Assert.assertTrue(entity.getContent() instanceof ChunkedInputStream);
     }
 
+    @Test
     public void testEntityWithIdentityTransferEncoding() throws Exception {
-        SessionInputBuffer datareceiver =
-            new SessionInputBufferMockup(new byte[] {});
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer =
+            new SessionInputBufferMock(new byte[] {});
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
@@ -103,15 +101,16 @@ public class TestEntityDeserializer extends TestCase {
         message.addHeader("Content-Length", "plain wrong");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(-1, entity.getContentLength());
-        assertFalse(entity.isChunked());
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(-1, entity.getContentLength());
+        Assert.assertFalse(entity.isChunked());
     }
 
+    @Test
     public void testEntityWithUnsupportedTransferEncoding() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup("0\r\n", "US-ASCII");
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock("0\r\n", "US-ASCII");
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
@@ -120,25 +119,26 @@ public class TestEntityDeserializer extends TestCase {
         message.addHeader("Content-Length", "plain wrong");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(-1, entity.getContentLength());
-        assertTrue(entity.isChunked());
-        assertTrue(entity.getContent() instanceof ChunkedInputStream);
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(-1, entity.getContentLength());
+        Assert.assertTrue(entity.isChunked());
+        Assert.assertTrue(entity.getContent() instanceof ChunkedInputStream);
 
         // strict mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, true);
         try {
-            entitygen.deserialize(datareceiver, message);
-            fail("ProtocolException should have been thrown");
+            entitygen.deserialize(inbuffer, message);
+            Assert.fail("ProtocolException should have been thrown");
         } catch (ProtocolException ex) {
             // expected
         }
     }
 
+    @Test
     public void testChunkedTransferEncodingMustBeLast() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup("0\r\n", "US-ASCII");
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock("0\r\n", "US-ASCII");
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
@@ -147,25 +147,26 @@ public class TestEntityDeserializer extends TestCase {
         message.addHeader("Content-Length", "plain wrong");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(-1, entity.getContentLength());
-        assertFalse(entity.isChunked());
-        assertFalse(entity.getContent() instanceof ChunkedInputStream);
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(-1, entity.getContentLength());
+        Assert.assertFalse(entity.isChunked());
+        Assert.assertFalse(entity.getContent() instanceof ChunkedInputStream);
 
         // strict mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, true);
         try {
-            entitygen.deserialize(datareceiver, message);
-            fail("ProtocolException should have been thrown");
+            entitygen.deserialize(inbuffer, message);
+            Assert.fail("ProtocolException should have been thrown");
         } catch (ProtocolException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityWithContentLength() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup(new byte[] {});
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock(new byte[] {});
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
@@ -173,16 +174,17 @@ public class TestEntityDeserializer extends TestCase {
         message.addHeader("Content-Length", "0");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(0, entity.getContentLength());
-        assertFalse(entity.isChunked());
-        assertTrue(entity.getContent() instanceof ContentLengthInputStream);
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(0, entity.getContentLength());
+        Assert.assertFalse(entity.isChunked());
+        Assert.assertTrue(entity.getContent() instanceof ContentLengthInputStream);
     }
 
+    @Test
     public void testEntityWithMultipleContentLength() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup(new byte[] {'0'});
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock(new byte[] {'0'});
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
@@ -192,27 +194,28 @@ public class TestEntityDeserializer extends TestCase {
         message.addHeader("Content-Length", "1");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(1, entity.getContentLength());
-        assertFalse(entity.isChunked());
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(1, entity.getContentLength());
+        Assert.assertFalse(entity.isChunked());
         InputStream instream = entity.getContent();
-        assertNotNull(instream);
-        assertTrue(instream instanceof ContentLengthInputStream);
+        Assert.assertNotNull(instream);
+        Assert.assertTrue(instream instanceof ContentLengthInputStream);
 
         // strict mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, true);
         try {
-            entitygen.deserialize(datareceiver, message);
-            fail("ProtocolException should have been thrown");
+            entitygen.deserialize(inbuffer, message);
+            Assert.fail("ProtocolException should have been thrown");
         } catch (ProtocolException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityWithMultipleContentLengthSomeWrong() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup(new byte[] {'0'});
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock(new byte[] {'0'});
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
@@ -222,27 +225,28 @@ public class TestEntityDeserializer extends TestCase {
         message.addHeader("Content-Length", "xxx");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(1, entity.getContentLength());
-        assertFalse(entity.isChunked());
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(1, entity.getContentLength());
+        Assert.assertFalse(entity.isChunked());
         InputStream instream = entity.getContent();
-        assertNotNull(instream);
-        assertTrue(instream instanceof ContentLengthInputStream);
+        Assert.assertNotNull(instream);
+        Assert.assertTrue(instream instanceof ContentLengthInputStream);
 
         // strict mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, true);
         try {
-            entitygen.deserialize(datareceiver, message);
-            fail("ProtocolException should have been thrown");
+            entitygen.deserialize(inbuffer, message);
+            Assert.fail("ProtocolException should have been thrown");
         } catch (ProtocolException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityWithMultipleContentLengthAllWrong() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup(new byte[] {'0'});
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock(new byte[] {'0'});
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
@@ -251,28 +255,29 @@ public class TestEntityDeserializer extends TestCase {
         message.addHeader("Content-Length", "xxx");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(-1, entity.getContentLength());
-        assertFalse(entity.isChunked());
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(-1, entity.getContentLength());
+        Assert.assertFalse(entity.isChunked());
         InputStream instream = entity.getContent();
-        assertNotNull(instream);
-        assertFalse(instream instanceof ContentLengthInputStream);
-        assertTrue(instream instanceof IdentityInputStream);
+        Assert.assertNotNull(instream);
+        Assert.assertFalse(instream instanceof ContentLengthInputStream);
+        Assert.assertTrue(instream instanceof IdentityInputStream);
 
         // strict mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, true);
         try {
-            entitygen.deserialize(datareceiver, message);
-            fail("ProtocolException should have been thrown");
+            entitygen.deserialize(inbuffer, message);
+            Assert.fail("ProtocolException should have been thrown");
         } catch (ProtocolException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityWithInvalidContentLength() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup(new byte[] {'0'});
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock(new byte[] {'0'});
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
@@ -280,68 +285,71 @@ public class TestEntityDeserializer extends TestCase {
         message.addHeader("Content-Length", "xxx");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(-1, entity.getContentLength());
-        assertFalse(entity.isChunked());
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(-1, entity.getContentLength());
+        Assert.assertFalse(entity.isChunked());
         InputStream instream = entity.getContent();
-        assertNotNull(instream);
-        assertFalse(instream instanceof ContentLengthInputStream);
-        assertTrue(instream instanceof IdentityInputStream);
+        Assert.assertNotNull(instream);
+        Assert.assertFalse(instream instanceof ContentLengthInputStream);
+        Assert.assertTrue(instream instanceof IdentityInputStream);
 
         // strict mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, true);
         try {
-            entitygen.deserialize(datareceiver, message);
-            fail("ProtocolException should have been thrown");
+            entitygen.deserialize(inbuffer, message);
+            Assert.fail("ProtocolException should have been thrown");
         } catch (ProtocolException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityNeitherContentLengthNorTransferEncoding() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup(new byte[] {'0'});
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock(new byte[] {'0'});
+        HttpMessage message = new DummyHttpMessage();
 
         // lenient mode
         message.getParams().setBooleanParameter(CoreProtocolPNames.STRICT_TRANSFER_ENCODING, false);
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertEquals(-1, entity.getContentLength());
-        assertFalse(entity.isChunked());
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertEquals(-1, entity.getContentLength());
+        Assert.assertFalse(entity.isChunked());
         InputStream instream = entity.getContent();
-        assertNotNull(instream);
-        assertFalse(instream instanceof ContentLengthInputStream);
-        assertFalse(instream instanceof ChunkedInputStream);
-        assertTrue(instream instanceof IdentityInputStream);
+        Assert.assertNotNull(instream);
+        Assert.assertFalse(instream instanceof ContentLengthInputStream);
+        Assert.assertFalse(instream instanceof ChunkedInputStream);
+        Assert.assertTrue(instream instanceof IdentityInputStream);
     }
 
+    @Test
     public void testEntityContentType() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup(new byte[] {'0'});
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock(new byte[] {'0'});
+        HttpMessage message = new DummyHttpMessage();
 
         message.addHeader("Content-Type", "stuff");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertNotNull(entity.getContentType());
-        assertEquals("stuff", entity.getContentType().getValue());
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertNotNull(entity.getContentType());
+        Assert.assertEquals("stuff", entity.getContentType().getValue());
     }
 
+    @Test
     public void testEntityContentEncoding() throws Exception {
-        SessionInputBuffer datareceiver = new SessionInputBufferMockup(new byte[] {'0'});
-        HttpMessage message = new HttpMessageMockup();
+        SessionInputBuffer inbuffer = new SessionInputBufferMock(new byte[] {'0'});
+        HttpMessage message = new DummyHttpMessage();
 
         message.addHeader("Content-Encoding", "what not");
         EntityDeserializer entitygen = new EntityDeserializer(
                 new LaxContentLengthStrategy());
-        HttpEntity entity = entitygen.deserialize(datareceiver, message);
-        assertNotNull(entity);
-        assertNotNull(entity.getContentEncoding());
-        assertEquals("what not", entity.getContentEncoding().getValue());
+        HttpEntity entity = entitygen.deserialize(inbuffer, message);
+        Assert.assertNotNull(entity);
+        Assert.assertNotNull(entity.getContentEncoding());
+        Assert.assertEquals("what not", entity.getContentEncoding().getValue());
     }
 
 }
