@@ -29,91 +29,91 @@ package org.apache.http.impl.entity;
 
 import java.io.OutputStream;
 
-import junit.framework.TestCase;
-
 import org.apache.http.HttpMessage;
 import org.apache.http.HttpVersion;
 import org.apache.http.ProtocolException;
 import org.apache.http.entity.ByteArrayEntity;
+import org.apache.http.impl.SessionOutputBufferMock;
 import org.apache.http.impl.io.ChunkedOutputStream;
 import org.apache.http.impl.io.ContentLengthOutputStream;
 import org.apache.http.impl.io.IdentityOutputStream;
 import org.apache.http.io.SessionOutputBuffer;
-import org.apache.http.mockup.HttpMessageMockup;
-import org.apache.http.mockup.SessionOutputBufferMockup;
 import org.apache.http.params.CoreProtocolPNames;
+import org.junit.Assert;
+import org.junit.Test;
 
-public class TestEntitySerializer extends TestCase {
-
-    public TestEntitySerializer(String testName) {
-        super(testName);
-    }
+public class TestEntitySerializer {
 
+    @Test
     public void testIllegalGenerateArg() throws Exception {
         EntitySerializer entitywriter = new EntitySerializer(
                 new StrictContentLengthStrategy());
         try {
             entitywriter.serialize(null, null, null);
-            fail("IllegalArgumentException should have been thrown");
+            Assert.fail("IllegalArgumentException should have been thrown");
         } catch (IllegalArgumentException ex) {
             // expected
         }
         try {
-            entitywriter.serialize(new SessionOutputBufferMockup() , null, null);
-            fail("IllegalArgumentException should have been thrown");
+            entitywriter.serialize(new SessionOutputBufferMock() , null, null);
+            Assert.fail("IllegalArgumentException should have been thrown");
         } catch (IllegalArgumentException ex) {
             // expected
         }
         try {
-            entitywriter.serialize(new SessionOutputBufferMockup() , new HttpMessageMockup(), null);
-            fail("IllegalArgumentException should have been thrown");
+            entitywriter.serialize(new SessionOutputBufferMock() , new DummyHttpMessage(), null);
+            Assert.fail("IllegalArgumentException should have been thrown");
         } catch (IllegalArgumentException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityWithChunkTransferEncoding() throws Exception {
-        SessionOutputBuffer datatransmitter = new SessionOutputBufferMockup();
-        HttpMessage message = new HttpMessageMockup();
+        SessionOutputBuffer outbuffer = new SessionOutputBufferMock();
+        HttpMessage message = new DummyHttpMessage();
         message.addHeader("Transfer-Encoding", "Chunked");
 
         EntitySerializer entitywriter = new EntitySerializer(
                 new StrictContentLengthStrategy());
-        OutputStream outstream = entitywriter.doSerialize(datatransmitter, message);
-        assertNotNull(outstream);
-        assertTrue(outstream instanceof ChunkedOutputStream);
+        OutputStream outstream = entitywriter.doSerialize(outbuffer, message);
+        Assert.assertNotNull(outstream);
+        Assert.assertTrue(outstream instanceof ChunkedOutputStream);
     }
 
+    @Test
     public void testEntityWithIdentityTransferEncoding() throws Exception {
-        SessionOutputBuffer datatransmitter = new SessionOutputBufferMockup();
-        HttpMessage message = new HttpMessageMockup();
+        SessionOutputBuffer outbuffer = new SessionOutputBufferMock();
+        HttpMessage message = new DummyHttpMessage();
         message.addHeader("Transfer-Encoding", "Identity");
 
         EntitySerializer entitywriter = new EntitySerializer(
                 new StrictContentLengthStrategy());
-        OutputStream outstream = entitywriter.doSerialize(datatransmitter, message);
-        assertNotNull(outstream);
-        assertTrue(outstream instanceof IdentityOutputStream);
+        OutputStream outstream = entitywriter.doSerialize(outbuffer, message);
+        Assert.assertNotNull(outstream);
+        Assert.assertTrue(outstream instanceof IdentityOutputStream);
     }
 
+    @Test
     public void testEntityWithInvalidTransferEncoding() throws Exception {
-        SessionOutputBuffer datatransmitter = new SessionOutputBufferMockup();
-        HttpMessage message = new HttpMessageMockup();
+        SessionOutputBuffer outbuffer = new SessionOutputBufferMock();
+        HttpMessage message = new DummyHttpMessage();
         message.addHeader("Transfer-Encoding", "whatever");
 
         EntitySerializer entitywriter = new EntitySerializer(
                 new StrictContentLengthStrategy());
         try {
-            entitywriter.doSerialize(datatransmitter, message);
-            fail("ProtocolException should have been thrown");
+            entitywriter.doSerialize(outbuffer, message);
+            Assert.fail("ProtocolException should have been thrown");
         } catch (ProtocolException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityWithInvalidChunkEncodingAndHTTP10() throws Exception {
-        SessionOutputBuffer datatransmitter = new SessionOutputBufferMockup();
-        HttpMessage message = new HttpMessageMockup();
+        SessionOutputBuffer outbuffer = new SessionOutputBufferMock();
+        HttpMessage message = new DummyHttpMessage();
         message.getParams().setParameter(CoreProtocolPNames.PROTOCOL_VERSION,
                 HttpVersion.HTTP_1_0);
         message.addHeader("Transfer-Encoding", "chunked");
@@ -121,64 +121,68 @@ public class TestEntitySerializer extends TestCase {
         EntitySerializer entitywriter = new EntitySerializer(
                 new StrictContentLengthStrategy());
         try {
-            entitywriter.doSerialize(datatransmitter, message);
-            fail("ProtocolException should have been thrown");
+            entitywriter.doSerialize(outbuffer, message);
+            Assert.fail("ProtocolException should have been thrown");
         } catch (ProtocolException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityWithContentLength() throws Exception {
-        SessionOutputBuffer datatransmitter = new SessionOutputBufferMockup();
-        HttpMessage message = new HttpMessageMockup();
+        SessionOutputBuffer outbuffer = new SessionOutputBufferMock();
+        HttpMessage message = new DummyHttpMessage();
         message.addHeader("Content-Length", "100");
         EntitySerializer entitywriter = new EntitySerializer(
                 new StrictContentLengthStrategy());
-        OutputStream outstream = entitywriter.doSerialize(datatransmitter, message);
-        assertNotNull(outstream);
-        assertTrue(outstream instanceof ContentLengthOutputStream);
+        OutputStream outstream = entitywriter.doSerialize(outbuffer, message);
+        Assert.assertNotNull(outstream);
+        Assert.assertTrue(outstream instanceof ContentLengthOutputStream);
     }
 
+    @Test
     public void testEntityWithInvalidContentLength() throws Exception {
-        SessionOutputBuffer datatransmitter = new SessionOutputBufferMockup();
-        HttpMessage message = new HttpMessageMockup();
+        SessionOutputBuffer outbuffer = new SessionOutputBufferMock();
+        HttpMessage message = new DummyHttpMessage();
         message.addHeader("Content-Length", "whatever");
 
         EntitySerializer entitywriter = new EntitySerializer(
                 new StrictContentLengthStrategy());
         try {
-            entitywriter.doSerialize(datatransmitter, message);
-            fail("ProtocolException should have been thrown");
+            entitywriter.doSerialize(outbuffer, message);
+            Assert.fail("ProtocolException should have been thrown");
         } catch (ProtocolException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEntityNoContentDelimiter() throws Exception {
-        SessionOutputBuffer datatransmitter = new SessionOutputBufferMockup();
-        HttpMessage message = new HttpMessageMockup();
+        SessionOutputBuffer outbuffer = new SessionOutputBufferMock();
+        HttpMessage message = new DummyHttpMessage();
         EntitySerializer entitywriter = new EntitySerializer(
                 new StrictContentLengthStrategy());
-        OutputStream outstream = entitywriter.doSerialize(datatransmitter, message);
-        assertNotNull(outstream);
-        assertTrue(outstream instanceof IdentityOutputStream);
+        OutputStream outstream = entitywriter.doSerialize(outbuffer, message);
+        Assert.assertNotNull(outstream);
+        Assert.assertTrue(outstream instanceof IdentityOutputStream);
     }
 
+    @Test
     public void testEntitySerialization() throws Exception {
         byte[] content = new byte[] {1, 2, 3, 4, 5};
         ByteArrayEntity entity = new ByteArrayEntity(content);
 
-        SessionOutputBufferMockup datatransmitter = new SessionOutputBufferMockup();
-        HttpMessage message = new HttpMessageMockup();
+        SessionOutputBufferMock outbuffer = new SessionOutputBufferMock();
+        HttpMessage message = new DummyHttpMessage();
         message.addHeader("Content-Length", Integer.toString(content.length));
 
         EntitySerializer entitywriter = new EntitySerializer(
                 new StrictContentLengthStrategy());
-        entitywriter.serialize(datatransmitter, message, entity);
+        entitywriter.serialize(outbuffer, message, entity);
 
-        byte[] data = datatransmitter.getData();
-        assertNotNull(data);
-        assertEquals(content.length, data.length);
+        byte[] data = outbuffer.getData();
+        Assert.assertNotNull(data);
+        Assert.assertEquals(content.length, data.length);
     }
 }
 
