@@ -32,81 +32,82 @@ import java.io.ByteArrayOutputStream;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 
-import junit.framework.TestCase;
+import org.junit.Assert;
+import org.junit.Test;
 
 /**
  * Unit tests for {@link ByteArrayBuffer}.
  *
  */
-public class TestByteArrayBuffer extends TestCase {
-
-    public TestByteArrayBuffer(String testName) {
-        super(testName);
-    }
+public class TestByteArrayBuffer {
 
+    @Test
     public void testConstructor() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(16);
-        assertEquals(16, buffer.capacity());
-        assertEquals(0, buffer.length());
-        assertNotNull(buffer.buffer());
-        assertEquals(16, buffer.buffer().length);
+        Assert.assertEquals(16, buffer.capacity());
+        Assert.assertEquals(0, buffer.length());
+        Assert.assertNotNull(buffer.buffer());
+        Assert.assertEquals(16, buffer.buffer().length);
         try {
             new ByteArrayBuffer(-1);
-            fail("IllegalArgumentException should have been thrown");
+            Assert.fail("IllegalArgumentException should have been thrown");
         } catch (IllegalArgumentException ex) {
             // expected
         }
     }
 
+    @Test
     public void testSimpleAppend() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(16);
-        assertEquals(16, buffer.capacity());
-        assertEquals(0, buffer.length());
+        Assert.assertEquals(16, buffer.capacity());
+        Assert.assertEquals(0, buffer.length());
         byte[] b1 = buffer.toByteArray();
-        assertNotNull(b1);
-        assertEquals(0, b1.length);
-        assertTrue(buffer.isEmpty());
-        assertFalse(buffer.isFull());
+        Assert.assertNotNull(b1);
+        Assert.assertEquals(0, b1.length);
+        Assert.assertTrue(buffer.isEmpty());
+        Assert.assertFalse(buffer.isFull());
 
         byte[] tmp = new byte[] { 1, 2, 3, 4};
         buffer.append(tmp, 0, tmp.length);
-        assertEquals(16, buffer.capacity());
-        assertEquals(4, buffer.length());
-        assertFalse(buffer.isEmpty());
-        assertFalse(buffer.isFull());
+        Assert.assertEquals(16, buffer.capacity());
+        Assert.assertEquals(4, buffer.length());
+        Assert.assertFalse(buffer.isEmpty());
+        Assert.assertFalse(buffer.isFull());
 
         byte[] b2 = buffer.toByteArray();
-        assertNotNull(b2);
-        assertEquals(4, b2.length);
+        Assert.assertNotNull(b2);
+        Assert.assertEquals(4, b2.length);
         for (int i = 0; i < tmp.length; i++) {
-            assertEquals(tmp[i], b2[i]);
-            assertEquals(tmp[i], buffer.byteAt(i));
+            Assert.assertEquals(tmp[i], b2[i]);
+            Assert.assertEquals(tmp[i], buffer.byteAt(i));
         }
         buffer.clear();
-        assertEquals(16, buffer.capacity());
-        assertEquals(0, buffer.length());
-        assertTrue(buffer.isEmpty());
-        assertFalse(buffer.isFull());
+        Assert.assertEquals(16, buffer.capacity());
+        Assert.assertEquals(0, buffer.length());
+        Assert.assertTrue(buffer.isEmpty());
+        Assert.assertFalse(buffer.isFull());
     }
 
+    @Test
     public void testExpandAppend() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(4);
-        assertEquals(4, buffer.capacity());
+        Assert.assertEquals(4, buffer.capacity());
 
         byte[] tmp = new byte[] { 1, 2, 3, 4};
         buffer.append(tmp, 0, 2);
         buffer.append(tmp, 0, 4);
         buffer.append(tmp, 0, 0);
 
-        assertEquals(8, buffer.capacity());
-        assertEquals(6, buffer.length());
+        Assert.assertEquals(8, buffer.capacity());
+        Assert.assertEquals(6, buffer.length());
 
         buffer.append(tmp, 0, 4);
 
-        assertEquals(16, buffer.capacity());
-        assertEquals(10, buffer.length());
+        Assert.assertEquals(16, buffer.capacity());
+        Assert.assertEquals(10, buffer.length());
     }
 
+    @Test
     public void testInvalidAppend() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(4);
         buffer.append((byte[])null, 0, 0);
@@ -114,82 +115,87 @@ public class TestByteArrayBuffer extends TestCase {
         byte[] tmp = new byte[] { 1, 2, 3, 4};
         try {
             buffer.append(tmp, -1, 0);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
         try {
             buffer.append(tmp, 0, -1);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
         try {
             buffer.append(tmp, 0, 8);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
         try {
             buffer.append(tmp, 10, Integer.MAX_VALUE);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
         try {
             buffer.append(tmp, 2, 4);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
     }
 
+    @Test
     public void testAppendOneByte() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(4);
-        assertEquals(4, buffer.capacity());
+        Assert.assertEquals(4, buffer.capacity());
 
         byte[] tmp = new byte[] { 1, 127, -1, -128, 1, -2};
         for (int i = 0; i < tmp.length; i++) {
             buffer.append(tmp[i]);
         }
-        assertEquals(8, buffer.capacity());
-        assertEquals(6, buffer.length());
+        Assert.assertEquals(8, buffer.capacity());
+        Assert.assertEquals(6, buffer.length());
 
         for (int i = 0; i < tmp.length; i++) {
-            assertEquals(tmp[i], buffer.byteAt(i));
+            Assert.assertEquals(tmp[i], buffer.byteAt(i));
         }
     }
 
+    @Test
     public void testSetLength() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(4);
         buffer.setLength(2);
-        assertEquals(2, buffer.length());
+        Assert.assertEquals(2, buffer.length());
     }
 
+    @Test
     public void testSetInvalidLength() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(4);
         try {
             buffer.setLength(-2);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
         try {
             buffer.setLength(200);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
     }
 
+    @Test
     public void testEnsureCapacity() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(4);
         buffer.ensureCapacity(2);
-        assertEquals(4, buffer.capacity());
+        Assert.assertEquals(4, buffer.capacity());
         buffer.ensureCapacity(8);
-        assertEquals(8, buffer.capacity());
+        Assert.assertEquals(8, buffer.capacity());
     }
 
+    @Test
     public void testIndexOf() throws Exception {
         final byte COLON = (byte) ':';
         final byte COMMA = (byte) ',';
@@ -200,14 +206,15 @@ public class TestByteArrayBuffer extends TestCase {
         ByteArrayBuffer buffer = new ByteArrayBuffer(16);
         buffer.append(bytes, 0, bytes.length);
 
-        assertEquals(index1, buffer.indexOf(COLON));
-        assertEquals(-1, buffer.indexOf(COMMA));
-        assertEquals(index1, buffer.indexOf(COLON, -1, 11));
-        assertEquals(index1, buffer.indexOf(COLON, 0, 1000));
-        assertEquals(-1, buffer.indexOf(COLON, 2, 1));
-        assertEquals(index2, buffer.indexOf(COLON, index1 + 1, buffer.length()));
+        Assert.assertEquals(index1, buffer.indexOf(COLON));
+        Assert.assertEquals(-1, buffer.indexOf(COMMA));
+        Assert.assertEquals(index1, buffer.indexOf(COLON, -1, 11));
+        Assert.assertEquals(index1, buffer.indexOf(COLON, 0, 1000));
+        Assert.assertEquals(-1, buffer.indexOf(COLON, 2, 1));
+        Assert.assertEquals(index2, buffer.indexOf(COLON, index1 + 1, buffer.length()));
     }
 
+    @Test
     public void testAppendCharArrayAsAscii() throws Exception {
         String s1 = "stuff";
         String s2 = " and more stuff";
@@ -218,27 +225,31 @@ public class TestByteArrayBuffer extends TestCase {
         buffer.append(b1, 0, b1.length);
         buffer.append(b2, 0, b2.length);
 
-        assertEquals(s1 + s2, new String(buffer.toByteArray(), "US-ASCII"));
+        Assert.assertEquals(s1 + s2, new String(buffer.toByteArray(), "US-ASCII"));
     }
 
+    @Test
     public void testAppendNullCharArray() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(8);
         buffer.append((char[])null, 0, 0);
-        assertEquals(0, buffer.length());
+        Assert.assertEquals(0, buffer.length());
     }
 
+    @Test
     public void testAppendEmptyCharArray() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(8);
         buffer.append(new char[] {}, 0, 0);
-        assertEquals(0, buffer.length());
+        Assert.assertEquals(0, buffer.length());
     }
 
+    @Test
     public void testAppendNullCharArrayBuffer() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(8);
         buffer.append((CharArrayBuffer)null, 0, 0);
-        assertEquals(0, buffer.length());
+        Assert.assertEquals(0, buffer.length());
     }
 
+    @Test
     public void testInvalidAppendCharArrayAsAscii() throws Exception {
         ByteArrayBuffer buffer = new ByteArrayBuffer(4);
         buffer.append((char[])null, 0, 0);
@@ -246,36 +257,37 @@ public class TestByteArrayBuffer extends TestCase {
         char[] tmp = new char[] { '1', '2', '3', '4'};
         try {
             buffer.append(tmp, -1, 0);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
         try {
             buffer.append(tmp, 0, -1);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
         try {
             buffer.append(tmp, 0, 8);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
         try {
             buffer.append(tmp, 10, Integer.MAX_VALUE);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
         try {
             buffer.append(tmp, 2, 4);
-            fail("IndexOutOfBoundsException should have been thrown");
+            Assert.fail("IndexOutOfBoundsException should have been thrown");
         } catch (IndexOutOfBoundsException ex) {
             // expected
         }
     }
 
+    @Test
     public void testSerialization() throws Exception {
         ByteArrayBuffer orig = new ByteArrayBuffer(32);
         orig.append(1);
@@ -289,14 +301,14 @@ public class TestByteArrayBuffer extends TestCase {
         ByteArrayInputStream inbuffer = new ByteArrayInputStream(raw);
         ObjectInputStream instream = new ObjectInputStream(inbuffer);
         ByteArrayBuffer clone = (ByteArrayBuffer) instream.readObject();
-        assertEquals(orig.capacity(), clone.capacity());
-        assertEquals(orig.length(), clone.length());
+        Assert.assertEquals(orig.capacity(), clone.capacity());
+        Assert.assertEquals(orig.length(), clone.length());
         byte[] data = clone.toByteArray();
-        assertNotNull(data);
-        assertEquals(3, data.length);
-        assertEquals(1, data[0]);
-        assertEquals(2, data[1]);
-        assertEquals(3, data[2]);
+        Assert.assertNotNull(data);
+        Assert.assertEquals(3, data.length);
+        Assert.assertEquals(1, data[0]);
+        Assert.assertEquals(2, data[1]);
+        Assert.assertEquals(3, data[2]);
     }
 
 }
